@@ -9,7 +9,7 @@ use base qw(
     Catalyst::Model
 );
 
-our $VERSION = '0.56';
+our $VERSION = '0.57';
 
 __PACKAGE__->mk_accessors(qw( object_class page_size ));
 
@@ -319,6 +319,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing List
+
+L<https://groups.google.com/forum/#!forum/catalystxcrud>
+
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/CatalystX-CRUD>
