@@ -16,6 +16,25 @@ __PACKAGE__->config(
     view_on_single_result => 1,
 );
 
+sub fetch : Chained('/') PathPrefix CaptureArgs(1) {
+    my ( $self, $c, $id ) = @_;
+    eval { $self->next::method( $c, $id ); };
+    if ($@) {
+
+        #$c->log->error($@) if $c->debug;
+        if ( $@ =~ m/^No such File/ ) {
+            my $file = $self->do_model( $c, 'new_object', file => $id );
+            $file = $self->do_model( $c, 'prep_new_object', $file );
+            $c->log->debug("empty file object:$file") if $c->debug;
+            $c->stash( object => $file );
+        }
+        else {
+            # re-throw
+            $self->throw_error($@);
+        }
+    }
+}
+
 # test the view_on_single_result method
 # search for a file where we know there is only one
 # and then check for a redirect response code
