@@ -21,6 +21,25 @@ __PACKAGE__->config(
     init_object => 'file_from_form',
 );
 
+sub fetch {
+    my ( $self, $c, $id ) = @_;
+    eval { $self->next::method( $c, $id ); };
+    if ($@) {
+
+        #$c->log->error($@) if $c->debug;
+        if ( $@ =~ m/^No such File/ ) {
+            my $file = $self->do_model( $c, 'new_object', file => $id );
+            $file = $self->do_model( $c, 'prep_new_object', $file );
+            $c->log->debug("empty file object:$file") if $c->debug;
+            $c->stash( object => $file );
+        }
+        else {
+            # re-throw
+            $self->throw_error($@);
+        }
+    }
+}
+
 sub do_search {
     my ( $self, $c, @arg ) = @_;
     $self->next::method( $c, @arg );
